LiveView for the catalogue activity events subtab.
Displays a filterable, infinite-scroll list of activity entries scoped to the "catalogue" module using LiveView streams.
LiveView for the catalogue activity events subtab.
Displays a filterable, infinite-scroll list of activity entries scoped to the "catalogue" module using LiveView streams.